==> alfred-ui-native-components-0.0.120.tgz: package/ui/molecules/headerTabs/default/index.tsx <==
import React, { FC } from 'react';
import { ScrollView, TouchableOpacity, View } from 'react-native';
import { LabelMediumText } from '../../../atoms';
import { styles } from '../styles';
import { HeaderTabItemModel } from '../headerTabsModels';

interface Props {
  tabsList?: HeaderTabItemModel[],
  onTabClick: (item: HeaderTabItemModel) => void,
}

export const HeaderTabs: FC<Props> = ({ tabsList, onTabClick }) => {
  return (
    <View style={styles.headerContainerBackground}>
      <ScrollView
        horizontal
        showsHorizontalScrollIndicator={false}
        contentContainerStyle={styles.headerContainer}
      >
        {tabsList && tabsList.map((item, key) => {
          const { text, isSelected } = item;
          const isLastItem = key === tabsList.length - 1;
          return (
            <TouchableOpacity
              key={key}
              style={
                [
                  styles.headerTabsTextContainer,
                  isSelected && styles.headerTabsTextContainerSelected,
                  isLastItem && styles.headerTabsTextContainerLastItem,
                ]
              }
              onPress={() => onTabClick(item)}
            >
              <LabelMediumText
                color={
                  isSelected
                    ? styles.headerTabsTextContainerText.isSelected.color
                    : styles.headerTabsTextContainerText.color}
              >
                {text}
              </LabelMediumText>
            </TouchableOpacity>
          );
        })}
      </ScrollView>
    </View>

  );
};

==> alfred-ui-native-components-0.0.158.tgz: package/ui/molecules/headerTabs/default/index.tsx <==
import React, { FC } from 'react';
import { ScrollView, View } from 'react-native';
import { LabelMediumText, TouchableOpacityButtonWrapper } from '../../../atoms';
import { styles } from '../styles';
import { HeaderTabItemModel } from '../headerTabsModels';

interface Props {
  tabsList?: HeaderTabItemModel[],
  onTabClick: (item: HeaderTabItemModel) => void,
}

export const HeaderTabs: FC<Props> = ({ tabsList, onTabClick }) => {
  return (
    <View style={styles.headerContainerBackground}>
      <ScrollView
        horizontal
        showsHorizontalScrollIndicator={false}
        contentContainerStyle={styles.headerContainer}
      >
        {tabsList && tabsList.map((item, key) => {
          const { text, isSelected } = item;
          const isLastItem = key === tabsList.length - 1;
          return (
            <TouchableOpacityButtonWrapper
              key={key}
              style={
                [
                  styles.headerTabsTextContainer,
                  isSelected && styles.headerTabsTextContainerSelected,
                  isLastItem && styles.headerTabsTextContainerLastItem,
                ]
              }
              onClick={() => onTabClick(item)}
            >
              <LabelMediumText
                color={
                  isSelected
                    ? styles.headerTabsTextContainerText.isSelected.color
                    : styles.headerTabsTextContainerText.color}
              >
                {text}
              </LabelMediumText>
            </TouchableOpacityButtonWrapper>
          );
        })}
      </ScrollView>
    </View>

  );
};
